Stream

Trait Stream 

pub trait Stream: AsyncRead + AsyncWrite { }
A stream that can be read from and written to asynchronously. This let’s us abstract over many async streams like tcp, ssl, udp, ssh, etc.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<S> Stream for S
where S: AsyncRead + AsyncWrite,