pub trait NetworkStream:
Read
+ Write
+ AsTcpStream { }Expand description
a Stream that can also be used as a borrow to a TcpStream
this is useful when you want to set TcpStream options on a
Stream like nonblocking.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".