Stream

Trait Stream 

pub trait Stream: Read + Write { }
Represents a stream that can be read from, and written to. This is an abstraction around readable and writable things to be able to speak websockets over ssl, tcp, unix sockets, etc.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<S> Stream for S
where S: Read + Write,